.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :caption: Contents
   :hidden:

   dev_guide
   api
   changelog

.. toctree::
   :caption: Links
   :hidden:

   GitHub <https://github.com/int-brain-lab/iblqt>
   PyPI <https://pypi.org/project/iblqt>